# Setup -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(tidystats)
library(ggpubr)

# Read raw data files
data <- read_csv("Data/clean_data.csv")

# descriptive statistics
long_var_names <- c("age", 
                    "partner_found", 
                    "follow_up", 
                    "social_distance_close",
                    "social_distance_common",
                    "uncertainty_nervous",
                    "uncertainty_worried",
                    "expectation",
                    "confidence",
                    "anticipated_satisfaction",
                    "anticipated_regret",
                    "experienced_satisfaction",
                    "experienced_regret",
                    "experiment_enjoyment",
                    "experiment_interesting",
                    "fairness_rules",
                    "fairness_procedure",
                    "perceived_realism",
                    "mini_dictator_decision_num",
                    "comprehension_correct",
                    "waiting_time")
long_data <- gather(data, key = "key", value = "value", long_var_names)
descriptives <- long_data %>%
  group_by(key) %>%
  describe_data(value, short=TRUE)

gender_table <- data %>%
  count_data(gender)

descriptives_by_condition <- long_data %>%
  group_by(condition, key) %>%
  describe_data(value, short=TRUE)

# compare comprehension by condition
comprehension <- chisq.test(data$comprehension_correct, data$condition)
summary(comprehension)

# primary analyses
# first question: Does pre-decision matching influence cooperation? (via social distance)
data_q1 <- filter(data, condition !="pre_immediate")
data_q1$condition_num <- as.numeric(recode_factor(data_q1$condition,
                                '.5' = "pre_delayed",
                                '-.5' = "post_delayed"))
model1_yx <-  glm(prisoners_dilemma_decision_num~condition, data=data_q1, family="binomial")
summary(model1_yx)
model1_mx <-  lm(social_distance_sum~condition, data=data_q1)
summary(model1_mx)
model1_ym <- glm(prisoners_dilemma_decision_num~social_distance_sum, data=data_q1, family="binomial")
summary(model1_ym)

# second question: Does delayed feedback influence cooperation? (via aversive uncertainty)
data_q2 <- filter(data, condition !="post_delayed")
data_q2$condition_num <- as.numeric(recode_factor(data_q2$condition,
                                                  '.5' = "pre_immediate",
                                                  '-.5' = "pre_delayed"))
model2_yx <-  glm(prisoners_dilemma_decision_num~condition, data=data_q2, family="binomial")
summary(model2_yx)
model2_mx <-  lm(aversive_uncertainty_sum~condition, data=data_q2)
summary(model2_mx)
model2_ym <- glm(prisoners_dilemma_decision_num~aversive_uncertainty_sum, data=data_q2, family="binomial")
summary(model2_ym)

# third question: Does condition moderate the effect of SVO on behavior?
model3a <- glm(prisoners_dilemma_decision_num~SVO_scale*pre_decision_matching + SVO_scale*immediate_feedback,
              data=data,
              family="binomial")
summary(model3a)
model3b <- lm(social_distance_sum~SVO_scale*pre_decision_matching + SVO_scale*immediate_feedback,
               data=data)
summary(model3b)
model3c <- lm(aversive_uncertainty_sum~SVO_scale*pre_decision_matching + SVO_scale*immediate_feedback,
               data=data)
summary(model3c)

# secondary analyses
# comprehension questions
data_comp <- filter(data, comprehension_correct==1)

# first question: Does pre-decision matching influence cooperation? (via social distance)
data_q1 <- filter(data_comp, condition !="pre_immediate")
data_q1$condition_num <- as.numeric(recode_factor(data_q1$condition,
                                                  '.5' = "pre_delayed",
                                                  '-.5' = "post_delayed"))
model1_yx_comp <-  glm(prisoners_dilemma_decision_num~condition, data=data_q1, family="binomial")
summary(model1_yx_comp)
model1_mx_comp <-  lm(social_distance_sum~condition, data=data_q1)
summary(model1_mx_comp)
model1_ymx_comp <- lm(prisoners_dilemma_decision_num~condition+social_distance_sum, data=data_q1, family="binomial")
summary(model1_ymx_comp)

# second question: Does delayed feedback influence cooperation? (via aversive uncertainty)
data_q2 <- filter(data_comp, condition !="post_delayed")
data_q2$condition_num <- as.numeric(recode_factor(data_q2$condition,
                                                  '.5' = "pre_immediate",
                                                  '-.5' = "pre_delayed"))
model2_yx_comp <-  glm(prisoners_dilemma_decision_num~condition, data=data_q2, family="binomial")
summary(model2_yx_comp)
model2_mx_comp <-  lm(aversive_uncertainty_sum~condition, data=data_q2)
summary(model2_mx_comp)
model2_ymx_comp <- lm(prisoners_dilemma_decision_num~condition+aversive_uncertainty_sum, data=data_q2, family="binomial")
summary(model2_ymx_comp)

# third question: Does condition moderate the effect of SVO on behavior?
model3_comp <- glm(prisoners_dilemma_decision_num~SVO_scale*pre_decision_matching + SVO_scale*immediate_feedback,
              data=data_comp,
              family="binomial")
summary(model3_comp)

# analyses including demographics as covariates
model1_yx_demo <-  glm(prisoners_dilemma_decision_num~condition + gender + age + income + english, data=data_q1, family="binomial")
summary(model1_yx_demo)
model2_yx_demo <-  glm(prisoners_dilemma_decision_num~condition + gender + age + income + english, data=data_q2, family="binomial")
summary(model2_yx_demo)
model3_demo <- glm(prisoners_dilemma_decision_num~SVO_scale*pre_decision_matching + SVO_scale*immediate_feedback + gender + age + income + english,
               data=data,
               family="binomial")
summary(model3_demo)

# does the manipulation affect additional measures
model_exp <- lm(expectation ~ pre_decision_matching + immediate_feedback,
             data=data)
summary(model_exp)
model_conf <- lm(confidence ~ pre_decision_matching + immediate_feedback,
                data=data)
summary(model_conf)
model_enjoy <- lm(experiment_enjoyment_sum ~ pre_decision_matching + immediate_feedback,
              data=data)
summary(model_enjoy)
model_real <- lm(perceived_realism ~ pre_decision_matching + immediate_feedback,
             data=data)
summary(model_real)
model_ant_sat <- lm(anticipated_satisfaction ~ pre_decision_matching + immediate_feedback,
                  data=data)
summary(model_ant_sat)
model_ant_reg <- lm(anticipated_regret ~ pre_decision_matching + immediate_feedback,
                 data=data)
summary(model_ant_reg)
model_exp_sat <- lm(experienced_satisfaction ~ pre_decision_matching + immediate_feedback,
                    data=data)
summary(model_exp_sat)
model_exp_reg <- lm(experienced_regret ~ pre_decision_matching + immediate_feedback,
                    data=data)
summary(model_exp_reg)

# post decision analyses
model4_expect <- lm(expectation ~ pre_decision_matching + immediate_feedback,
                    data=data)
summary(model4_expect)
model4_conf <- lm(confidence ~ pre_decision_matching + immediate_feedback,
                 data=data)
summary(model4_conf)
model4_ant_sat <- lm(anticipated_satisfaction ~ pre_decision_matching + immediate_feedback,
                   data=data)
summary(model4_ant_sat)
model4_ant_reg <- lm(anticipated_regret ~ pre_decision_matching + immediate_feedback,
                     data=data)
summary(model4_ant_reg)

# post feedback measures
model5_dict <- glm(mini_dictator_decision_num~ pre_decision_matching*payoff_scale + immediate_feedback*payoff_scale,
                   data = data, family="binomial")
model5_enjoy <- lm(experiment_enjoyment_sum~ pre_decision_matching*payoff_scale + immediate_feedback*payoff_scale,
                   data = data)
model5_exp_reg <- lm(experienced_regret~ pre_decision_matching*payoff_scale + immediate_feedback*payoff_scale,
                     data = data)
model5_exp_sat <- lm(experienced_satisfaction~ pre_decision_matching*payoff_scale + immediate_feedback*payoff_scale,
                     data = data)
model5_fair <- lm(fairness_sum~ pre_decision_matching*payoff_scale + immediate_feedback*payoff_scale,
                     data = data)
model5_real <- lm(perceived_realism~ pre_decision_matching*payoff_scale + immediate_feedback*payoff_scale,
                  data = data)
summary(model5_dict)
summary(model5_enjoy)
summary(model5_exp_reg)
summary(model5_exp_sat)
summary(model5_real)
summary(model5_fair)

# does waiting time influence cooperation
r_time_coop <- cor.test(data$waiting_time_log, data$prisoners_dilemma_decision_num)
r_time_distance <- cor.test(data$waiting_time_log, data$social_distance_sum)
r_time_uncertain <- cor.test(data$waiting_time_log, data$aversive_uncertainty_sum)
r_time_realism <- cor.test(data$waiting_time_log, data$perceived_realism)

# make figure 1
data$condition <- factor(data$condition,
                            levels = c("pre_immediate", "pre_delayed", "post_delayed"),
                            labels = c("fully synchronous", "partially synchronous", "asynchronous"))
data <- subset(data, !is.na(prisoners_dilemma_decision_num))
plot1a <- ggplot(data, aes(condition, prisoners_dilemma_decision_num)) +
  geom_bar(stat = "summary", fun = mean, position = "dodge", fill = "gray80") +
  stat_summary(aes(label = round(..y.., 2)), fun= "mean", geom = "text", size = 10, hjust = 2) +
  ylim(0,1) +
  coord_flip() +
  theme_bw() +
  theme_bw(base_size = 24) +
  theme(axis.title = element_blank()) +
  ggtitle('A. cooperation')
plot1b <- ggplot(data, aes(y=social_distance_sum, x=condition)) +
  geom_violin(lwd=1) +
  geom_boxplot(width=0.2, lwd=1, fill = "gray80") +
  coord_flip() +
  theme_bw() +
  theme_bw(base_size = 24) +
  theme(axis.title = element_blank()) +
  ggtitle("B. social distance")
plot1c <- ggplot(data, aes(y=aversive_uncertainty_sum, x=condition)) +
  geom_violin(lwd=1) +
  geom_boxplot(width=0.2, lwd=1, fill = "gray80") +
  coord_flip() +
  theme_bw() +
  theme_bw(base_size = 24) +
  theme(axis.title = element_blank()) +
  ggtitle("C. aversive uncertainty")

ggarrange(plot1a, plot1b, plot1c, ncol=1, nrow=3)

# Create an empty list
results <- list()

# Add the analyses to the empty list
results <- results %>%
  add_stats(descriptives, notes = "descriptives") %>%
  add_stats(descriptives_by_condition, notes = "descriptives by condition") %>%
  add_stats(gender_table, notes = "gender table") %>%
  add_stats(comprehension, notes = "comprehension by condition") %>%
  add_stats(model1_yx, notes = "cooperation ~ matching") %>%
  add_stats(model1_mx, notes = "social distance ~ matching") %>%
  add_stats(model1_ym, notes = "cooperation ~ social distance") %>%
  add_stats(model2_yx, notes = "cooperation ~ feedback") %>%
  add_stats(model2_mx, notes = "aversive uncertainty ~ feedback") %>%
  add_stats(model2_ym, notes = "cooperation ~ aversive uncertainty") %>%
  add_stats(model3a, notes = "cooperation ~ svo*condition") %>%
  add_stats(model3b, notes = "social distance ~ svo*condition") %>%
  add_stats(model3c, notes = "aversive uncertainty ~ svo*condition") %>%
  add_stats(model4_expect, notes = "expectations ~ condition") %>%
  add_stats(model4_conf, notes = "confidence ~ condition") %>%
  add_stats(model4_ant_sat, notes = "anticipated satisfaction ~ condition") %>%
  add_stats(model4_ant_reg, notes = "anticipated regret ~ condition") %>%
  add_stats(model5_dict, notes = "dictator game ~ svo*condition") %>%
  add_stats(model5_enjoy, notes = "enjoyment of experiment ~ svo*condition") %>%
  add_stats(model5_exp_reg, notes = "experienced regret ~ condition") %>%
  add_stats(model5_exp_sat, notes = "experienced satisfaction ~ condition") %>%
  add_stats(model5_real, notes = "perceived realness ~ condition") %>%
  add_stats(model5_fair, notes = "perceived fairness ~ condition") %>%
  add_stats(model1_yx_comp, notes = "cooperation ~ pre matching, comprehension") %>%
  add_stats(model2_yx_comp, notes = "cooperation ~ pre matching, comprehension") %>%
  add_stats(model3_comp, notes = "cooperation ~ condition x SVO, comprehension") %>%
  add_stats(model1_yx_demo, notes = "cooperation ~ pre matching, demographics") %>%
  add_stats(model2_yx_demo, notes = "cooperation ~ pre matching, demographics") %>%
  add_stats(model3_demo, notes = "cooperation ~ condition x SVO, demographics")

# write stats file
write_stats(results, "results.json")
