
# Setup -------------------------------------------------------------------

# Load packages
library(tidyverse)

# Load custom functions
not_all_na <- function(x) {!all(is.na(x))}

# Read raw data files
data_november <- read_csv("Data/all_apps_wide_2020-11-29_no_id.csv")
data_february <- read_csv("Data/all_apps_wide_2021-02-10_no_id.csv", guess_max = 2000)

# Data preparation --------------------------------------------------------

# Join the two data files
data <- bind_rows(data_november, data_february)

# Remove empty rows
data <- filter(data, participant.visited == 1)

# Remove demo sessions
data <- filter(data, session.is_demo != 1)

# Remove empty columns
data <- select_if(data, not_all_na)

# Rename columns
data <- rename(data,
    code_participant = participant.code,
    code_session = session.code,
    date = participant.time_started,
    condition = session.config.condition,
    mediation_questions_order = session.config.mediation_questions_order,
    prolific_id1 = new_id_1,
    comprehension_transfer_transfer = 
      prisoner_dilemma_check.1.player.comprehension_transfer_transfer,
    comprehension_keep_keep = 
      prisoner_dilemma_check.1.player.comprehension_keep_keep,
    comprehension_keep_transfer = 
      prisoner_dilemma_check.1.player.comprehension_keep_transfer,
    comprehension_transfer_keep = 
      prisoner_dilemma_check.1.player.comprehension_transfer_keep,
    experienced_satisfaction = 
      post_feedback_questions.1.player.experienced_satisfaction,
    experienced_regret = post_feedback_questions.1.player.experienced_regret,
    mini_dictator_decision = post_feedback_questions.1.player.mini_dictator_decision,
    experiment_enjoyment = post_feedback_questions.1.player.experiment_enjoyment,
    experiment_interesting = post_feedback_questions.1.player.experiment_interesting,
    fairness_rules = post_feedback_questions.1.player.perceived_fairness_rules,
    fairness_procedure = post_feedback_questions.1.player.perceived_fairness_procedure,
    perceived_realism = post_feedback_questions.1.player.perceived_realism,
    gender = demographics.1.player.gender,
    age = demographics.1.player.age,
    english = demographics.1.player.english,
    income = demographics.1.player.income,
    political_orientation = demographics.1.player.political_orientation,
    device = demographics.1.player.device,
    payoff = participant.payoff
  )

# Combine columns that contain the same information but that are in separate
# columns because they were in different conditions
data <- mutate(data,
    prolific_id2 = coalesce(
      new_id_2,
      new_id_3
    ),
    waiting_time = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.waiting_time, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.waiting_time
    ),
    partner_found = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.partner_found,
      prisoner_dilemma_pre_matching_delayed_feedback_results.1.player.partner_found
    ),
    partner_stayed = coalesce(
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.partner_stayed,
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.partner_stayed
    ),
    prisoners_dilemma_decision = coalesce(
      prisoner_dilemma_post_matching_delayed_feedback.1.player.decision,
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.decision,
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.decision
    ),
    social_distance_close = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.social_distance_close, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.social_distance_close, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.social_distance_close
    ),
    social_distance_common = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.social_distance_common, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.social_distance_common, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.social_distance_common
    ),
    uncertainty_nervous = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.aversive_uncertainty_nervous, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.aversive_uncertainty_nervous, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.aversive_uncertainty_nervous
    ),
    uncertainty_worried = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.aversive_uncertainty_worried, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.aversive_uncertainty_worried, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.aversive_uncertainty_worried
    ),
    expectation = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.post_PD_expectation, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.post_PD_expectation, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.post_PD_expectation
    ),
    confidence = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.post_PD_confidence, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.post_PD_confidence, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.post_PD_confidence
    ),
    anticipated_satisfaction = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.post_PD_satisfied, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.post_PD_satisfied, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.post_PD_satisfied
    ),
    anticipated_regret = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.post_PD_regret, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.post_PD_regret, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.post_PD_regret
    ),
    SVO1 = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.SVO1, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.SVO1, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.SVO1
    ),
    SVO2 = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.SVO2, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.SVO2, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.SVO2
    ),
    SVO3 = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.SVO3, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.SVO3, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.SVO3
    ),
    SVO4 = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.SVO4, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.SVO4, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.SVO4
    ),
    SVO5 = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.SVO5, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.SVO5, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.SVO5
    ),
    SVO6 = coalesce(
      prisoner_dilemma_pre_matching_immediate_feedback.1.player.SVO6, 
      prisoner_dilemma_pre_matching_delayed_feedback.1.player.SVO6, 
      prisoner_dilemma_post_matching_delayed_feedback.1.player.SVO6
    ),
  )

# Separate the data into separate data frames for part 1 and part 2 of the study
# and per condition
sessions_part1 <- c("2zspntdi", "5xvgpd2w", "luior2ot", "p9v6ros7", "rkp04l55",
  "43jl5n8c", "hg6txgur", "y4bojul5", "cejdkb4n", "np9oz9z1", "ztdijxk3",
  "lsdf5hwd"
)
sessions_part2 <- c("1ryg3ot3", "tort5dsd", "zzh42zve", "y76u8gfg", "ed2ocfxz",
  "qihy15cs", "i964ilrl", "m20founf"
)

data_pre_immediate <- filter(data, condition == "pre_immediate")
data_part1_pre_delayed <- filter(data, condition == "pre_delayed" & 
    code_session %in% sessions_part1)
data_part2_pre_delayed <- filter(data,
    code_session %in% c("1ryg3ot3", "tort5dsd", "zzh42zve", "i964ilrl"))
data_part1_post_delayed <- filter(data, condition == "post_delayed" & 
    code_session %in% sessions_part1)
data_part2_post_delayed <- filter(data,
    code_session %in% c("ed2ocfxz", "m20founf", "qihy15cs", "y76u8gfg" ))

# Select relevant columns for each data frame
data_pre_immediate <- select(data_pre_immediate, code_participant, code_session,
  date, condition, payoff, mediation_questions_order, prolific_id1, 
  starts_with("comprehension"), waiting_time, partner_found, 
  partner_stayed, prisoners_dilemma_decision, social_distance_close, 
  social_distance_common, uncertainty_nervous, uncertainty_worried, expectation, 
  confidence, anticipated_satisfaction, anticipated_regret, 
  starts_with("SVO"), experienced_satisfaction, experienced_regret,
  experiment_enjoyment, experiment_interesting, fairness_rules, 
  fairness_procedure, perceived_realism, mini_dictator_decision, gender, age, 
  english, income, political_orientation, device
  )

data_part1_pre_delayed <- select(data_part1_pre_delayed, code_participant, 
  code_session, date, condition, mediation_questions_order,
  prolific_id1, starts_with("comprehension"), waiting_time, 
  prisoners_dilemma_decision, social_distance_close, 
  social_distance_common, uncertainty_nervous, uncertainty_worried, expectation, 
  confidence, anticipated_satisfaction, anticipated_regret, 
  starts_with("SVO"))

data_part2_pre_delayed <- select(data_part2_pre_delayed, code_participant, 
  code_session, date, prolific_id2, partner_found, payoff,
  experienced_satisfaction, experienced_regret,
  experiment_enjoyment, experiment_interesting, fairness_rules, 
  fairness_procedure, perceived_realism, mini_dictator_decision, gender, age, 
  english, income, political_orientation, device)

data_part1_post_delayed <- select(data_part1_post_delayed, code_participant, 
  code_session, date, condition, mediation_questions_order,
  prolific_id1, starts_with("comprehension"), prisoners_dilemma_decision, 
  social_distance_close, social_distance_common, uncertainty_nervous, 
  uncertainty_worried, expectation, confidence, anticipated_satisfaction, 
  anticipated_regret, starts_with("SVO"))

data_part2_post_delayed <- select(data_part2_post_delayed, code_participant, 
  code_session, date, prolific_id2, experienced_satisfaction, payoff,
  experienced_regret, experiment_enjoyment, experiment_interesting, 
  fairness_rules, fairness_procedure, perceived_realism, mini_dictator_decision,
  gender, age, english, income, political_orientation, device
  )

# Rename some of the columns before merging
data_pre_immediate <- rename(data_pre_immediate, 
    prolific_id = prolific_id1, 
    date1 = date,
    code_participant1 = code_participant,
    code_session1 = code_session
  )

data_part1_pre_delayed <- rename(data_part1_pre_delayed,
    prolific_id = prolific_id1, 
    date1 = date,
    code_participant1 = code_participant,
    code_session1 = code_session
  )

data_part2_pre_delayed <- rename(data_part2_pre_delayed,
    prolific_id = prolific_id2, 
    date2 = date,
    code_participant2 = code_participant,
    code_session2 = code_session
)

data_part1_post_delayed <- rename(data_part1_post_delayed,
    prolific_id = prolific_id1, 
    date1 = date,
    code_participant1 = code_participant,
    code_session1 = code_session,
  )

data_part2_post_delayed <- rename(data_part2_post_delayed,
    prolific_id = prolific_id2, 
    date2 = date,
    code_participant2 = code_participant,
    code_session2 = code_session
)

# Merge data sets
data_pre_delayed <- left_join(data_part1_pre_delayed, data_part2_pre_delayed, 
  by = "prolific_id")
data_post_delayed <- left_join(data_part1_post_delayed, data_part2_post_delayed, 
  by = "prolific_id")

data <- bind_rows(data_pre_immediate, data_pre_delayed, data_post_delayed)

# Reorder columns
data <- relocate(data, date1, date2, code_participant1, code_participant2, 
  code_session1, code_session2, prolific_id)

# remove participants without prolific IDs
data <- filter(data, prolific_id != "" | !is.na(prolific_id))

# dealing with weird observations
data <- distinct(data, prolific_id, .keep_all = TRUE)

# calculate summary scores for social distance, aversive uncertainty, and experiment enjoyment
data$social_distance_sum <- (20 - data$social_distance_close - data$social_distance_common)/2
data$aversive_uncertainty_sum <- (data$uncertainty_nervous + data$uncertainty_worried)/2
data$experiment_enjoyment_sum <- (data$experiment_enjoyment + data$experiment_interesting)/2
data$fairness_sum <- (data$fairness_procedure + data$fairness_rules)/2

# calculate SVO angles for each participant
data <- separate(data, SVO1, c("SVO1_self", "SVO1_other"), convert=TRUE)
data <- separate(data, SVO2, c("SVO2_self", "SVO2_other"), convert=TRUE)
data <- separate(data, SVO3, c("SVO3_self", "SVO3_other"), convert=TRUE)
data <- separate(data, SVO4, c("SVO4_self", "SVO4_other"), convert=TRUE)
data <- separate(data, SVO5, c("SVO5_self", "SVO5_other"), convert=TRUE)
data <- separate(data, SVO6, c("SVO6_self", "SVO6_other"), convert=TRUE)
data$SVO_self_total <- (data$SVO1_self + data$SVO2_self + data$SVO3_self + data$SVO4_self + data$SVO5_self + data$SVO6_self)-50
data$SVO_other_total <- (data$SVO1_other + data$SVO2_other + data$SVO3_other + data$SVO4_other + data$SVO5_other + data$SVO6_other)-50
data$SVO_angle <- atan(data$SVO_other_total/data$SVO_self_total)*180/pi

# recode cooperation into numeric
data$prisoners_dilemma_decision_num <- ifelse(data$prisoners_dilemma_decision=="Transfer", 1, 0)

# recode mini dictator into numeric
data$mini_dictator_decision_num <- ifelse(data$mini_dictator_decision=="Right", 1, 0)

# create variable indicating follow up in part 2
data$follow_up <- ifelse(is.na(data$code_participant2), 0, 1)

# scale SVO
data$SVO_scale <- scale(data$SVO_angle, scale=FALSE, center=TRUE)

# payoff scale
data$payoff_scale <- (data$payoff-200)/200

# create condition variables
data$pre_decision_matching <- ifelse(data$condition == "post_delayed", -.5, .5)
data$immediate_feedback <- ifelse(data$condition == "pre_immediate", .5, -.5)

# create a comprehension check variable
data$comprehension_correct <- ifelse(
  data$comprehension_transfer_transfer == 200 &
    data$comprehension_keep_keep == 100 &
    data$comprehension_keep_transfer == 300 &
    data$comprehension_transfer_keep == 0, 1, 0)

# log transform waiting time
data$waiting_time <- data$waiting_time/1000
data$waiting_time_log <- log10(data$waiting_time+1)

# write clean data file
write.csv(data, "Data/clean_data.csv")